# Image Bucket

Bucket a list of images into subdirectories with one key press (per image).

This will show you each image. Use j/k for next/previous, q to quit and confirm. Any other letter or number will tag that image to go to a subdirectory of that name. E.g. hit "a" to put the image under `a/`.
